import pandas as pd
from dash import Dash, Input, Output, dcc, html
import plotly.graph_objects as go
import plotly.express as px

data = (
    pd.read_csv("inventarioA.csv")
)


Visitas_e = 4
Etapas_e = 3
Comidas_E1_e = 42
Comidas_E2_e = 9
Comidas_E3_e = 9
Comidas_totales_e = Comidas_E1_e + Comidas_E2_e + Comidas_E3_e
Glucometro_e = 42
Total_pacientes = len(data.index)

scat = px.scatter(data, x="Days_glucose", y="Selectedfoods",size="medibles")
external_stylesheets = [
    {
        "href": (
            "https://fonts.googleapis.com/css2?"
            "family=Lato:wght@400;700&display=swap"
        ),
        "rel": "stylesheet",
    },
]
app = Dash(__name__, external_stylesheets=external_stylesheets)
app.title = "Nutridmex. Inventario de datos"

app.layout = html.Div(
    children=[
        html.Div(
            children=[
                html.P(children="🥑", className="header-emoji"),
                html.H1(
                    children="Inventario de datos", className="header-title"
                ),
                html.P(
                    children=(
                        "Recuento de los datos asociados a cada participante "
                    ),
                    className="header-description",
                ),
            ],
            className="header",
        ),
        html.Div(children=[
            html.Div(children=[
                "Min. Comidas",
                dcc.Slider(
                    id="min_comida",
                    min=1,
                    max=Comidas_totales_e,
                    value=Comidas_totales_e,
                #    marks={10:"babjo", 50:"medio", 100:"alto"}
                ),
                "Dias con Glucómetro",
                dcc.Slider(
                    id="min_glucosa",
                    min=1,
                    max=Glucometro_e,
                    value=Glucometro_e,
                    #marks={10:"low", 50:"medium", 100:"alto"})
                    ),
                "Visitas",
                dcc.Slider(
                    id="min_visitas",
                    min=1,
                    max=Visitas_e,
                    value=Visitas_e,
                    marks={1:"1", 2:"2", 3:"3", 4:"4"}
                    ),
                "Microbiota",
                dcc.Slider(
                    id="min_microbiota",
                    min=1,
                    max=Visitas_e,
                    value=Visitas_e,
                    marks={1:"1", 2:"2", 3:"3", 4:"4"}
                    )
                
            ]
            ),
            html.Div(children=[ 
            dcc.Graph(id="multi-chart")],
                     )],style={'display': 'flex', 'flexDirection': 'row'},
                 className="wrapper"),
        html.Div(
            children=[
                html.Div("Aqui van las gráficas de food analisis", className="wrapper"),
                dcc.Graph(
                    figure={
                        "data": [
                            {
                                "y":data["medibles"],
                                "x":data["nutrid"],
                                "type":"bar"
                            },
                        ],


                        "layout": {"title":"Comidas analizables por paciente"}
                    }),
                dcc.Graph(
                    figure=scat),

                ],
            className="wrapper"
            )
    ]
)


@app.callback(
    Output("multi-chart", "figure"),    
    Input("min_comida", "value"),
    Input("min_glucosa", "value"),
    Input("min_microbiota", "value"),                    
    Input("min_visitas", "value"),

)
def update_charts(min_comida, min_glucosa, min_microbiota, min_visitas):
    total_data = len(data.index)
    gauges = {
            'shape': "bullet",
            'axis': {'range': [None, 100]},
            'steps': [
                {'range': [0, 25], 'color': "red"},
                {'range': [25, 75], 'color': "yellow"},
                {'range': [75, 100], 'color': "green"}],            
            'bar': {'color': "blue"},
        }
    numbers = { 'suffix':'%', 'valueformat':'d'}
    modes = "number+gauge"


    multi = go.Figure()


    comidas_data = data.query("Selectedfoods >= @min_comida")
    multi.add_trace(go.Indicator(
        value = 100 * comidas_data["medibles"].count() / Total_pacientes,
        domain = {'x': [0.25, 1], 'y': [0.90, 1]},
        title = {'text': "Comidas"},
        mode = modes,
        number = numbers,
        gauge = gauges,
    ))

    glucosa_data = data.query("Days_glucose >= @min_glucosa") 
    multi.add_trace(go.Indicator(
        value = 100 * glucosa_data["medibles"].count() / Total_pacientes,
        domain = {'x': [0.25, 1], 'y': [0.8, 0.9]},
        title = {'text': "Glucómetro"},
        mode = modes,
        number = numbers,
        gauge = gauges
    ))

    medibles_data = data.query("medibles >= @min_comida") 
    multi.add_trace(go.Indicator(
        value = 100 * medibles_data["medibles"].count() / Total_pacientes,
        domain = {'x': [0.25, 1], 'y': [0.7, 0.8]},
        title = {'text': "Comidas/glucómetro"},
        mode = modes,
        number = numbers,
        gauge = gauges
    ))

    relojes_data = data.query("ConPasos > 0") 
    multi.add_trace(go.Indicator(
        value = 100 * relojes_data["medibles"].count() / Total_pacientes,
        domain = {'x': [0.25, 1], 'y': [0.6, 0.7]},
        title = {'text': "Reloj"},
        mode = modes,
        number = numbers,
        gauge = gauges
    ))
    
    microbiota_data = data.query("MT >= @min_microbiota") 
    multi.add_trace(go.Indicator(
        value = 100 * microbiota_data["medibles"].count() / Total_pacientes,
#        value = min_microbiota,
        domain = {'x': [0.25, 1], 'y': [0.5, 0.6]},
        title = {'text': "Microbiota"},
        mode = modes,
        number = numbers,
        gauge = gauges
    ))

    visitas_data = data.query("Nvisitas >= @min_visitas") 
    multi.add_trace(go.Indicator(
        value = 100 * visitas_data["medibles"].count() / Total_pacientes,
        domain = {'x': [0.25, 1], 'y':[0.1, 0.2]},
        title = {'text': "Visitas"},
        mode = modes,
        number = numbers,
        gauge = gauges
    ))    

    return   multi


if __name__ == "__main__":
    app.run_server(debug=True, port=8051)
